==> jc-1.4.0.tar.gz: gnu/classpath/ServiceFactory__24ServiceIterator.h <==
// final class gnu.classpath.ServiceFactory$ServiceIterator

// class file dependencies
// @dep_class c1f9e2588c73d8d gnu_classpath_ServiceFactory__24ServiceIterator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_ServiceFactory__24ServiceIterator_H_
#define _JC_gnu_classpath_ServiceFactory__24ServiceIterator_H_

// Forward structure declarations
struct _jc_java_io_BufferedReader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_net_URL$object;
struct _jc_java_security_AccessControlContext$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_refs	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_refs;
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_nonrefs	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_nonrefs;
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$refs	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$refs;
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$nonrefs	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$nonrefs;
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$object;

typedef const struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vmethods	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vmethods;
typedef const struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtable	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtable;
typedef const struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype;

// Constructors
extern void _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$_init$871808a21a9e5af7(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *, struct _jc_java_lang_Class$object *, struct _jc_object *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_security_AccessControlContext$object *);

// Virtual methods
extern void _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$advanceReader$c28e9e1aa193578b(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);
extern jboolean _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$loadNextServiceProvider$64800a80f105ca5b(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);
extern void _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$advanceReader$c28e9e1aa193578b;
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$loadNextServiceProvider$64800a80f105ca5b;
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vmethods {
	void	(*advanceReader$c28e9e1aa193578b)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);
	struct _jc_java_lang_Object$object	*(*loadNextServiceProvider$64800a80f105ca5b)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *);
};

// Vtable
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vmethods	gnu_classpath_ServiceFactory__24ServiceIterator;
};

// Vtype
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype {
	_jc_type			type;
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_refs {
	struct _jc_java_lang_Class$object	*spi;
	struct _jc_object	*urls;
	struct _jc_java_lang_ClassLoader$object	*loader;
	struct _jc_java_security_AccessControlContext$object	*securityContext;
	struct _jc_java_io_BufferedReader$object	*reader;
	struct _jc_java_net_URL$object	*currentURL;
	struct _jc_java_lang_Object$object	*nextProvider;
};

// Reference instance fields (object)
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$refs {
    _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_refs	gnu_classpath_ServiceFactory__24ServiceIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_nonrefs	gnu_classpath_ServiceFactory__24ServiceIterator;
};

// Object instance structure
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object {
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype	*vtype;
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype _jc_gnu_classpath_ServiceFactory__24ServiceIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_ServiceFactory__24ServiceIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_ServiceFactory__24ServiceIterator$class_object;

#endif	/* _JC_gnu_classpath_ServiceFactory__24ServiceIterator_H_ */

==> jc-1.4.6.tar.gz: gnu/classpath/ServiceFactory__24ServiceIterator.h <==
// final class gnu.classpath.ServiceFactory$ServiceIterator

// class file dependencies
// @dep_class c1f9e2588c73d8d gnu_classpath_ServiceFactory__24ServiceIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_classpath_ServiceFactory__24ServiceIterator_H_
#define _JC_gnu_classpath_ServiceFactory__24ServiceIterator_H_

// Forward structure declarations
struct _jc_java_io_BufferedReader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_net_URL$object;
struct _jc_java_security_AccessControlContext$object;
struct _jc_java_util_Enumeration$object;

// Typedefs
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_refs	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_refs;
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_nonrefs	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_nonrefs;
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$refs	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$refs;
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$nonrefs	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$nonrefs;
typedef struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$object;

typedef const struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vmethods	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vmethods;
typedef const struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtable	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtable;
typedef const struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype;

// Constructors
extern void _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$_init$871808a21a9e5af7(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *, struct _jc_java_lang_Class$object *, struct _jc_object *, struct _jc_java_lang_ClassLoader$object *, struct _jc_java_security_AccessControlContext$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$advanceReader$c28e9e1aa193578b(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$loadNextServiceProvider$64800a80f105ca5b(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$advanceReader$c28e9e1aa193578b;
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$loadNextServiceProvider$64800a80f105ca5b;
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_gnu_classpath_ServiceFactory__24ServiceIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vmethods {
	void	(*advanceReader$c28e9e1aa193578b)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*loadNextServiceProvider$64800a80f105ca5b)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vmethods	gnu_classpath_ServiceFactory__24ServiceIterator;
};

// Vtype
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype {
	_jc_type			type;
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_refs {
	struct _jc_java_lang_Class$object	*spi;
	struct _jc_object	*urls;
	struct _jc_java_lang_ClassLoader$object	*loader;
	struct _jc_java_security_AccessControlContext$object	*securityContext;
	struct _jc_java_io_BufferedReader$object	*reader;
	struct _jc_java_net_URL$object	*currentURL;
	struct _jc_java_lang_Object$object	*nextProvider;
};

// Reference instance fields (object)
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$refs {
    _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_refs	gnu_classpath_ServiceFactory__24ServiceIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_classpath_ServiceFactory__24ServiceIterator$sub_nonrefs	gnu_classpath_ServiceFactory__24ServiceIterator;
};

// Object instance structure
struct _jc_gnu_classpath_ServiceFactory__24ServiceIterator$object {
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype	*vtype;
	_jc_gnu_classpath_ServiceFactory__24ServiceIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_classpath_ServiceFactory__24ServiceIterator$vtype _jc_gnu_classpath_ServiceFactory__24ServiceIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_classpath_ServiceFactory__24ServiceIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_classpath_ServiceFactory__24ServiceIterator$class_object;

#endif	/* _JC_gnu_classpath_ServiceFactory__24ServiceIterator_H_ */
